//  GNOME Do is the legal property of its developers, whose names are too numerous
//  to list here.  Please refer to the COPYRIGHT file distributed with this
//  source distribution.
//
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.

using System;
using Do.Universe;

namespace Do.Interface
{
	public class ResultsWindowSelectionEventArgs : EventArgs
	{
		int index;
		Item selection;

		public ResultsWindowSelectionEventArgs (int index, Item selection)
		{
			this.index = index;
			this.selection = selection;
		}

		public int SelectedIndex
		{
			get { return index; }
		}

		public Item SelectedObject
		{
			get {
				return selection;
			}
		}
	}
}

